|Python version| |Python version windows| |Build Status| |Documentation|

Cosmic Ray: mutation testing for Python
=======================================


   "Four human beings -- changed by space-born cosmic rays into something more than merely human."
   
   -- The Fantastic Four

Cosmic Ray is a mutation testing tool for Python 3.

It makes small changes to your source code, running your test suite for each
one. Here's how the mutations look:

.. image:: docs/source/cr-in-action.gif

|full_documentation|_

Contributing
------------

The easiest way to contribute is to use Cosmic Ray and submit reports for defects or any other issues you come across.
Please see CONTRIBUTING.rst for more details.

.. |Python version| image:: https://img.shields.io/badge/Python_version-3.5+-blue.svg
   :target: https://www.python.org/
.. |Python version windows| image:: https://img.shields.io/badge/Python_version_(windows)-3.7+-blue.svg
   :target: https://www.python.org/
.. |Build Status| image:: https://github.com/sixty-north/cosmic-ray/actions/workflows/python-package.yml/badge.svg
   :target: https://github.com/sixty-north/cosmic-ray/actions/workflows/python-package.yml
.. |Code Health| image:: https://landscape.io/github/sixty-north/cosmic-ray/master/landscape.svg?style=flat
   :target: https://landscape.io/github/sixty-north/cosmic-ray/master
.. |Code Coverage| image:: https://codecov.io/gh/sixty-north/cosmic-ray/branch/master/graph/badge.svg
   :target: https://codecov.io/gh/Vimjas/covimerage/branch/master
.. |Documentation| image:: https://readthedocs.org/projects/cosmic-ray/badge/?version=latest
   :target: http://cosmic-ray.readthedocs.org/en/latest/
.. |full_documentation| replace:: **Read the full documentation at readthedocs.**
.. _full_documentation: http://cosmic-ray.readthedocs.org/en/latest/
